@@ -21,9 +21,10 @@ package org.apache.maven.archiver;
 
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.DependencyResolutionRequiredException;
+import org.apache.maven.artifact.versioning.ArtifactVersion;
+import org.apache.maven.artifact.versioning.OverConstrainedVersionException;
 import org.apache.maven.execution.MavenSession;
 import org.apache.maven.project.MavenProject;
-import org.codehaus.plexus.archiver.ArchiverException;
 import org.codehaus.plexus.archiver.jar.JarArchiver;
 import org.codehaus.plexus.archiver.jar.Manifest;
 import org.codehaus.plexus.archiver.jar.ManifestException;
@@ -48,24 +49,37 @@ import java.util.Set;
 
 /**
  * @author <a href="evenisse@apache.org">Emmanuel Venisse</a>
- * @version $Revision: 1634380 $ $Date: 2014-10-26 20:01:23 +0100 (Sun, 26 Oct 2014) $
+ * @author kama
+ * @version $Revision: 1748306 $ $Date: 2016-06-13 21:33:58 +0200 (Mon, 13 Jun 2016) $
  */
 public class MavenArchiver
 {
 
+    /**
+     * The simply layout.
+     */
     public static final String SIMPLE_LAYOUT =
         "${artifact.artifactId}-${artifact.version}${dashClassifier?}.${artifact.extension}";
 
-    public static final String REPOSITORY_LAYOUT = "${artifact.groupIdPath}/${artifact.artifactId}/" +
-        "${artifact.baseVersion}/${artifact.artifactId}-" +
-        "${artifact.version}${dashClassifier?}.${artifact.extension}";
+    /**
+     * Repository layout.
+     */
+    public static final String REPOSITORY_LAYOUT =
+        "${artifact.groupIdPath}/${artifact.artifactId}/" + "${artifact.baseVersion}/${artifact.artifactId}-"
+            + "${artifact.version}${dashClassifier?}.${artifact.extension}";
 
+    /**
+     * simple layout non unique.
+     */
     public static final String SIMPLE_LAYOUT_NONUNIQUE =
         "${artifact.artifactId}-${artifact.baseVersion}${dashClassifier?}.${artifact.extension}";
 
-    public static final String REPOSITORY_LAYOUT_NONUNIQUE = "${artifact.groupIdPath}/${artifact.artifactId}/" +
-        "${artifact.baseVersion}/${artifact.artifactId}-" +
-        "${artifact.baseVersion}${dashClassifier?}.${artifact.extension}";
+    /**
+     * Repository layout non unique.
+     */
+    public static final String REPOSITORY_LAYOUT_NONUNIQUE =
+        "${artifact.groupIdPath}/${artifact.artifactId}/" + "${artifact.baseVersion}/${artifact.artifactId}-"
+            + "${artifact.baseVersion}${dashClassifier?}.${artifact.extension}";
 
     private static final List<String> ARTIFACT_EXPRESSION_PREFIXES;
 
@@ -82,25 +96,13 @@ public class MavenArchiver
     private File archiveFile;
 
     /**
-     * Return a pre-configured manifest
-     *
-     * @param project the project
-     * @param config  the configuration to use
-     * @return a manifest, clients are recommended to use java.util.jar.Manifest datatype.
-     * @throws org.apache.maven.artifact.DependencyResolutionRequiredException
-     *          .
-     * @throws org.codehaus.plexus.archiver.jar.ManifestException
-     *          .
-     * @todo Add user attributes list and user groups list
-     * @deprecated
+     * @param session The Maven Session.
+     * @param project The Maven Project.
+     * @param config The MavenArchiveConfiguration
+     * @return The {@link Manifest}
+     * @throws ManifestException In case of a failure.
+     * @throws DependencyResolutionRequiredException Resolution failure.
      */
-    @SuppressWarnings ("UnusedDeclaration")
-    public Manifest getManifest( MavenProject project, MavenArchiveConfiguration config )
-        throws ManifestException, DependencyResolutionRequiredException
-    {
-        return getManifest( null, project, config );
-    }
-
     public Manifest getManifest( MavenSession session, MavenProject project, MavenArchiveConfiguration config )
         throws ManifestException, DependencyResolutionRequiredException
     {
@@ -119,10 +121,10 @@ public class MavenArchiver
                 String key = entry.getKey();
                 String value = entry.getValue();
                 Manifest.Attribute attr = manifest.getMainSection().getAttribute( key );
-                if ( key.equals( "Class-Path" ) && attr != null )
+                if ( key.equals( "ClassPath" ) && attr != null )
                 {
                     // Merge the user-supplied Class-Path value with the programmatically
-                    // generated Class-Path.  Note that the user-supplied value goes first
+                    // created Class-Path. Note that the user-supplied value goes first
                     // so that resources there will override any in the standard Class-Path.
                     attr.setValue( value + " " + attr.getValue() );
                 }
@@ -164,14 +166,27 @@ public class MavenArchiver
     /**
      * Return a pre-configured manifest
      *
-     * @todo Add user attributes list and user groups list
+     * @param project {@link MavenProject}
+     * @param config {@link ManifestConfiguration}
+     * @return {@link Manifest}
+     * @throws ManifestException Manifest exception.
+     * @throws DependencyResolutionRequiredException Dependency resolution exception.
      */
+    // TODO Add user attributes list and user groups list
     public Manifest getManifest( MavenProject project, ManifestConfiguration config )
         throws ManifestException, DependencyResolutionRequiredException
     {
         return getManifest( null, project, config, Collections.<String, String>emptyMap() );
     }
 
+    /**
+     * @param mavenSession {@link MavenSession}
+     * @param project {@link MavenProject}
+     * @param config {@link ManifestConfiguration}
+     * @return {@link Manifest}
+     * @throws ManifestException The manifest exception.
+     * @throws DependencyResolutionRequiredException The dependency resolution required exception.
+     */
     public Manifest getManifest( MavenSession mavenSession, MavenProject project, ManifestConfiguration config )
         throws ManifestException, DependencyResolutionRequiredException
     {
@@ -183,7 +198,7 @@ public class MavenArchiver
     {
         if ( map.containsKey( key ) )
         {
-            return;  // The map value will be added later
+            return; // The map value will be added later
         }
         addManifestAttribute( manifest, key, value );
     }
@@ -205,9 +220,18 @@ public class MavenArchiver
         }
     }
 
+    /**
+     * @param session {@link MavenSession}
+     * @param project {@link MavenProject}
+     * @param config {@link ManifestConfiguration}
+     * @param entries The entries.
+     * @return {@link Manifest}
+     * @throws ManifestException The manifest exception.
+     * @throws DependencyResolutionRequiredException The dependency resolution required exception.
+     */
     protected Manifest getManifest( MavenSession session, MavenProject project, ManifestConfiguration config,
                                     Map<String, String> entries )
-        throws ManifestException, DependencyResolutionRequiredException
+                                        throws ManifestException, DependencyResolutionRequiredException
     {
         // TODO: Should we replace "map" with a copy? Note, that we modify it!
 
@@ -221,7 +245,7 @@ public class MavenArchiver
         {
             StringBuilder classpath = new StringBuilder();
 
-            @SuppressWarnings ("unchecked") List<String> artifacts = project.getRuntimeClasspathElements();
+            List<String> artifacts = project.getRuntimeClasspathElements();
             String classpathPrefix = config.getClasspathPrefix();
             String layoutType = config.getClasspathLayoutType();
             String layout = config.getCustomClasspathLayout();
@@ -233,8 +257,7 @@ public class MavenArchiver
                 File f = new File( artifactFile );
                 if ( f.getAbsoluteFile().isFile() )
                 {
-                    @SuppressWarnings ("unchecked") Artifact artifact =
-                        findArtifactWithFile( project.getArtifacts(), f );
+                    Artifact artifact = findArtifactWithFile( project.getArtifacts(), f );
 
                     if ( classpath.length() > 0 )
                     {
@@ -242,7 +265,8 @@ public class MavenArchiver
                     }
                     classpath.append( classpathPrefix );
 
-                    // NOTE: If the artifact or layout type (from config) is null, give up and use the file name by itself.
+                    // NOTE: If the artifact or layout type (from config) is null, give up and use the file name by
+                    // itself.
                     if ( artifact == null || layoutType == null )
                     {
                         classpath.append( f.getName() );
@@ -250,36 +274,8 @@ public class MavenArchiver
                     else
                     {
                         List<ValueSource> valueSources = new ArrayList<ValueSource>();
-                        valueSources.add(
-                            new PrefixedObjectValueSource( ARTIFACT_EXPRESSION_PREFIXES, artifact, true ) );
-                        valueSources.add( new PrefixedObjectValueSource( ARTIFACT_EXPRESSION_PREFIXES, artifact == null
-                            ? null
-                            : artifact.getArtifactHandler(), true ) );
 
-                        Properties extraExpressions = new Properties();
-                        if ( artifact != null )
-                        {
-                            // FIXME: This query method SHOULD NOT affect the internal
-                            // state of the artifact version, but it does.
-                            if ( !artifact.isSnapshot() )
-                            {
-                                extraExpressions.setProperty( "baseVersion", artifact.getVersion() );
-                            }
-
-                            extraExpressions.setProperty( "groupIdPath", artifact.getGroupId().replace( '.', '/' ) );
-                            if ( StringUtils.isNotEmpty( artifact.getClassifier() ) )
-                            {
-                                extraExpressions.setProperty( "dashClassifier", "-" + artifact.getClassifier() );
-                                extraExpressions.setProperty( "dashClassifier?", "-" + artifact.getClassifier() );
-                            }
-                            else
-                            {
-                                extraExpressions.setProperty( "dashClassifier", "" );
-                                extraExpressions.setProperty( "dashClassifier?", "" );
-                            }
-                        }
-                        valueSources.add(
-                            new PrefixedPropertiesValueSource( ARTIFACT_EXPRESSION_PREFIXES, extraExpressions, true ) );
+                        handleExtraExpression( artifact, valueSources );
 
                         for ( ValueSource vs : valueSources )
                         {
@@ -299,23 +295,23 @@ public class MavenArchiver
                                 }
                                 else
                                 {
-                                    classpath.append(
-                                        interpolator.interpolate( SIMPLE_LAYOUT_NONUNIQUE, recursionInterceptor ) );
+                                    classpath.append( interpolator.interpolate( SIMPLE_LAYOUT_NONUNIQUE,
+                                                                                recursionInterceptor ) );
                                 }
                             }
                             else if ( ManifestConfiguration.CLASSPATH_LAYOUT_TYPE_REPOSITORY.equals( layoutType ) )
                             {
                                 // we use layout /$groupId[0]/../${groupId[n]/$artifactId/$version/{fileName}
-                                // here we must find the Artifact in the project Artifacts to generate the maven layout
+                                // here we must find the Artifact in the project Artifacts to create the maven layout
                                 if ( config.isUseUniqueVersions() )
                                 {
-                                    classpath.append(
-                                        interpolator.interpolate( REPOSITORY_LAYOUT, recursionInterceptor ) );
+                                    classpath.append( interpolator.interpolate( REPOSITORY_LAYOUT,
+                                                                                recursionInterceptor ) );
                                 }
                                 else
                                 {
-                                    classpath.append(
-                                        interpolator.interpolate( REPOSITORY_LAYOUT_NONUNIQUE, recursionInterceptor ) );
+                                    classpath.append( interpolator.interpolate( REPOSITORY_LAYOUT_NONUNIQUE,
+                                                                                recursionInterceptor ) );
                                 }
                             }
                             else if ( ManifestConfiguration.CLASSPATH_LAYOUT_TYPE_CUSTOM.equals( layoutType ) )
@@ -323,7 +319,8 @@ public class MavenArchiver
                                 if ( layout == null )
                                 {
                                     throw new ManifestException( ManifestConfiguration.CLASSPATH_LAYOUT_TYPE_CUSTOM
-                                                                     + " layout type was declared, but custom layout expression was not specified. Check your <archive><manifest><customLayout/> element." );
+                                        + " layout type was declared, but custom layout expression was not"
+                                        + " specified. Check your <archive><manifest><customLayout/> element." );
                                 }
 
                                 classpath.append( interpolator.interpolate( layout, recursionInterceptor ) );
@@ -331,13 +328,14 @@ public class MavenArchiver
                             else
                             {
                                 throw new ManifestException( "Unknown classpath layout type: '" + layoutType
-                                                                 + "'. Check your <archive><manifest><layoutType/> element." );
+                                    + "'. Check your <archive><manifest><layoutType/> element." );
                             }
                         }
                         catch ( InterpolationException e )
                         {
-                            ManifestException error = new ManifestException(
-                                "Error interpolating artifact path for classpath entry: " + e.getMessage() );
+                            ManifestException error =
+                                new ManifestException( "Error interpolating artifact path for classpath entry: "
+                                    + e.getMessage() );
 
                             error.initCause( e );
                             throw error;
@@ -363,31 +361,12 @@ public class MavenArchiver
 
         if ( config.isAddDefaultSpecificationEntries() )
         {
-            addManifestAttribute( m, entries, "Specification-Title", project.getName() );
-            addManifestAttribute( m, entries, "Specification-Version", project.getVersion() );
-
-            if ( project.getOrganization() != null )
-            {
-                addManifestAttribute( m, entries, "Specification-Vendor", project.getOrganization().getName() );
-            }
+            handleSpecificationEntries( project, entries, m );
         }
 
         if ( config.isAddDefaultImplementationEntries() )
         {
-            addManifestAttribute( m, entries, "Implementation-Title", project.getName() );
-            addManifestAttribute( m, entries, "Implementation-Version", project.getVersion() );
-            // MJAR-5
-            addManifestAttribute( m, entries, "Implementation-Vendor-Id", project.getGroupId() );
-
-            if ( project.getOrganization() != null )
-            {
-                addManifestAttribute( m, entries, "Implementation-Vendor", project.getOrganization().getName() );
-            }
-
-            if ( project.getUrl() != null )
-            {
-                addManifestAttribute( m, entries, "Implementation-URL", project.getUrl() );
-            }
+            handleImplementationEntries( project, entries, m );
         }
 
         String mainClass = config.getMainClass();
@@ -396,57 +375,134 @@ public class MavenArchiver
             addManifestAttribute( m, entries, "Main-Class", mainClass );
         }
 
-        // Added extensions
         if ( config.isAddExtensions() )
         {
-            // TODO: this is only for applets - should we distinguish them as a packaging?
-            StringBuilder extensionsList = new StringBuilder();
-            @SuppressWarnings ("unchecked") Set<Artifact> artifacts = (Set<Artifact>) project.getArtifacts();
+            handleExtensions( project, entries, m );
+        }
 
-            for ( Artifact artifact : artifacts )
-            {
-                if ( !Artifact.SCOPE_TEST.equals( artifact.getScope() ) )
-                {
-                    if ( "jar".equals( artifact.getType() ) )
-                    {
-                        if ( extensionsList.length() > 0 )
-                        {
-                            extensionsList.append( " " );
-                        }
-                        extensionsList.append( artifact.getArtifactId() );
-                    }
-                }
-            }
+        return m;
+    }
 
-            if ( extensionsList.length() > 0 )
-            {
-                addManifestAttribute( m, entries, "Extension-List", extensionsList.toString() );
-            }
+    private void handleExtraExpression( Artifact artifact, List<ValueSource> valueSources )
+    {
+        valueSources.add( new PrefixedObjectValueSource( ARTIFACT_EXPRESSION_PREFIXES, artifact,
+                                                         true ) );
+        valueSources.add( new PrefixedObjectValueSource( ARTIFACT_EXPRESSION_PREFIXES,
+                                                         artifact.getArtifactHandler(), true ) );
 
-            for ( Object artifact1 : artifacts )
+        Properties extraExpressions = new Properties();
+        // FIXME: This query method SHOULD NOT affect the internal
+        // state of the artifact version, but it does.
+        if ( !artifact.isSnapshot() )
+        {
+            extraExpressions.setProperty( "baseVersion", artifact.getVersion() );
+        }
+
+        extraExpressions.setProperty( "groupIdPath", artifact.getGroupId().replace( '.', '/' ) );
+        if ( StringUtils.isNotEmpty( artifact.getClassifier() ) )
+        {
+            extraExpressions.setProperty( "dashClassifier", "-" + artifact.getClassifier() );
+            extraExpressions.setProperty( "dashClassifier?", "-" + artifact.getClassifier() );
+        }
+        else
+        {
+            extraExpressions.setProperty( "dashClassifier", "" );
+            extraExpressions.setProperty( "dashClassifier?", "" );
+        }
+        valueSources.add( new PrefixedPropertiesValueSource( ARTIFACT_EXPRESSION_PREFIXES,
+                                                             extraExpressions, true ) );
+    }
+
+    private void handleExtensions( MavenProject project, Map<String, String> entries, Manifest m )
+        throws ManifestException
+    {
+        // TODO: this is only for applets - should we distinguish them as a packaging?
+        StringBuilder extensionsList = new StringBuilder();
+        Set<Artifact> artifacts = (Set<Artifact>) project.getArtifacts();
+
+        for ( Artifact artifact : artifacts )
+        {
+            if ( !Artifact.SCOPE_TEST.equals( artifact.getScope() ) )
             {
-                // TODO: the correct solution here would be to have an extension type, and to read
-                // the real extension values either from the artifact's manifest or some part of the POM
-                Artifact artifact = (Artifact) artifact1;
                 if ( "jar".equals( artifact.getType() ) )
                 {
-                    String artifactId = artifact.getArtifactId().replace( '.', '_' );
-                    String ename = artifactId + "-Extension-Name";
-                    addManifestAttribute( m, entries, ename, artifact.getArtifactId() );
-                    String iname = artifactId + "-Implementation-Version";
-                    addManifestAttribute( m, entries, iname, artifact.getVersion() );
-
-                    if ( artifact.getRepository() != null )
+                    if ( extensionsList.length() > 0 )
                     {
-                        iname = artifactId + "-Implementation-URL";
-                        String url = artifact.getRepository().getUrl() + "/" + artifact.toString();
-                        addManifestAttribute( m, entries, iname, url );
+                        extensionsList.append( " " );
                     }
+                    extensionsList.append( artifact.getArtifactId() );
                 }
             }
         }
 
-        return m;
+        if ( extensionsList.length() > 0 )
+        {
+            addManifestAttribute( m, entries, "Extension-List", extensionsList.toString() );
+        }
+
+        for ( Object artifact1 : artifacts )
+        {
+            // TODO: the correct solution here would be to have an extension type, and to read
+            // the real extension values either from the artifact's manifest or some part of the POM
+            Artifact artifact = (Artifact) artifact1;
+            if ( "jar".equals( artifact.getType() ) )
+            {
+                String artifactId = artifact.getArtifactId().replace( '.', '_' );
+                String ename = artifactId + "-Extension-Name";
+                addManifestAttribute( m, entries, ename, artifact.getArtifactId() );
+                String iname = artifactId + "-Implementation-Version";
+                addManifestAttribute( m, entries, iname, artifact.getVersion() );
+
+                if ( artifact.getRepository() != null )
+                {
+                    iname = artifactId + "-Implementation-URL";
+                    String url = artifact.getRepository().getUrl() + "/" + artifact.toString();
+                    addManifestAttribute( m, entries, iname, url );
+                }
+            }
+        }
+    }
+
+    private void handleImplementationEntries( MavenProject project, Map<String, String> entries, Manifest m )
+        throws ManifestException
+    {
+        addManifestAttribute( m, entries, "Implementation-Title", project.getName() );
+        addManifestAttribute( m, entries, "Implementation-Version", project.getVersion() );
+        // MJAR-5
+        addManifestAttribute( m, entries, "Implementation-Vendor-Id", project.getGroupId() );
+
+        if ( project.getOrganization() != null )
+        {
+            addManifestAttribute( m, entries, "Implementation-Vendor", project.getOrganization().getName() );
+        }
+
+        if ( project.getUrl() != null )
+        {
+            addManifestAttribute( m, entries, "Implementation-URL", project.getUrl() );
+        }
+    }
+
+    private void handleSpecificationEntries( MavenProject project, Map<String, String> entries, Manifest m )
+        throws ManifestException
+    {
+        addManifestAttribute( m, entries, "Specification-Title", project.getName() );
+
+        try
+        {
+            ArtifactVersion version = project.getArtifact().getSelectedVersion();
+            String specVersion = String.format( "%s.%s", version.getMajorVersion(), version.getMinorVersion() );
+            addManifestAttribute( m, entries, "Specification-Version", specVersion );
+        }
+        catch ( OverConstrainedVersionException e )
+        {
+            throw new ManifestException( "Failed to get selected artifact version to calculate"
+                + " the specification version: " + e.getMessage() );
+        }
+
+        if ( project.getOrganization() != null )
+        {
+            addManifestAttribute( m, entries, "Specification-Vendor", project.getOrganization().getName() );
+        }
     }
 
     private void addCustomEntries( Manifest m, Map<String, String> entries, ManifestConfiguration config )
@@ -455,64 +511,59 @@ public class MavenArchiver
         addManifestAttribute( m, entries, "Built-By", System.getProperty( "user.name" ) );
         addManifestAttribute( m, entries, "Build-Jdk", System.getProperty( "java.version" ) );
 
-/* TODO: rethink this, it wasn't working
-        Artifact projectArtifact = project.getArtifact();
-
-        if ( projectArtifact.isSnapshot() )
-        {
-            Manifest.Attribute buildNumberAttr = new Manifest.Attribute( "Build-Number", "" +
-                project.getSnapshotDeploymentBuildNumber() );
-            m.addConfiguredAttribute( buildNumberAttr );
-        }
-
-*/
+        /*
+         * TODO: rethink this, it wasn't working Artifact projectArtifact = project.getArtifact(); if (
+         * projectArtifact.isSnapshot() ) { Manifest.Attribute buildNumberAttr = new Manifest.Attribute( "Build-Number",
+         * "" + project.getSnapshotDeploymentBuildNumber() ); m.addConfiguredAttribute( buildNumberAttr ); }
+         */
         if ( config.getPackageName() != null )
         {
             addManifestAttribute( m, entries, "Package", config.getPackageName() );
         }
     }
 
+    /**
+     * @return {@link JarArchiver}
+     */
     public JarArchiver getArchiver()
     {
         return archiver;
     }
 
+    /**
+     * @param archiver {@link JarArchiver}
+     */
     public void setArchiver( JarArchiver archiver )
     {
         this.archiver = archiver;
     }
 
+    /**
+     * @param outputFile Set output file.
+     */
     public void setOutputFile( File outputFile )
     {
         archiveFile = outputFile;
     }
 
     /**
-     * @deprecated
+     * @param session {@link MavenSession}
+     * @param project {@link MavenProject}
+     * @param archiveConfiguration {@link MavenArchiveConfiguration}
+     * @throws org.codehaus.plexus.archiver.ArchiverException Archiver Exception.
+     * @throws ManifestException Manifest Exception.
+     * @throws IOException IO Exception.
+     * @throws DependencyResolutionRequiredException Dependency resolution exception.
      */
-    @SuppressWarnings ("JavaDoc")
-    public void createArchive( MavenProject project, MavenArchiveConfiguration archiveConfiguration )
-        throws ArchiverException, ManifestException, IOException, DependencyResolutionRequiredException
-    {
-        createArchive( null, project, archiveConfiguration );
-    }
-
     public void createArchive( MavenSession session, MavenProject project,
                                MavenArchiveConfiguration archiveConfiguration )
-        throws ArchiverException, ManifestException, IOException, DependencyResolutionRequiredException
+                                   throws ManifestException, IOException,
+                                   DependencyResolutionRequiredException
     {
         // we have to clone the project instance so we can write out the pom with the deployment version,
         // without impacting the main project instance...
         MavenProject workingProject = null;
-        try
-        {
-            workingProject = (MavenProject) project.clone();
-        }
-        catch (CloneNotSupportedException e)
-        {
-            // Should never happen
-            throw new ArchiverException( "Failed to clone Maven project", e );
-        }
+        workingProject = (MavenProject) project.clone();
 
         boolean forced = archiveConfiguration.isForced();
         if ( archiveConfiguration.isAddMavenDescriptor() )
@@ -543,13 +594,12 @@ public class MavenArchiver
             // Create pom.properties file
             // ----------------------------------------------------------------------
 
-            File pomPropertiesFile = archiveConfiguration.getPomPropertiesFile();
-            if ( pomPropertiesFile == null )
-            {
-                File dir = new File( workingProject.getBuild().getDirectory(), "maven-archiver" );
-                pomPropertiesFile = new File( dir, "pom.properties" );
-            }
-            new PomPropertiesUtil().createPomProperties( workingProject, archiver, pomPropertiesFile, forced );
+            File customPomPropertiesFile = archiveConfiguration.getPomPropertiesFile();
+            File dir = new File( workingProject.getBuild().getDirectory(), "maven-archiver" );
+            File pomPropertiesFile = new File( dir, "pom.properties" );
+
+            new PomPropertiesUtil().createPomProperties( session, workingProject, archiver,
+                customPomPropertiesFile, pomPropertiesFile, forced );
         }
 
         // ----------------------------------------------------------------------
@@ -579,7 +629,7 @@ public class MavenArchiver
         // make the archiver index the jars on the classpath, if we are adding that to the manifest
         if ( archiveConfiguration.getManifest().isAddClasspath() )
         {
-            @SuppressWarnings ("unchecked") List<String> artifacts = project.getRuntimeClasspathElements();
+            List<String> artifacts = project.getRuntimeClasspathElements();
             for ( String artifact : artifacts )
             {
                 File f = new File( artifact );
@@ -591,7 +641,8 @@ public class MavenArchiver
         if ( !archiveConfiguration.isForced() && archiver.isSupportingForced() )
         {
             // TODO Should issue a warning here, but how do we get a logger?
-            // TODO getLog().warn( "Forced build is disabled, but disabling the forced mode isn't supported by the archiver." );
+            // TODO getLog().warn(
+            // "Forced build is disabled, but disabling the forced mode isn't supported by the archiver." );
         }
 
         // create archive
@@ -604,7 +655,7 @@ public class MavenArchiver
         String createdBy = "Apache Maven";
         if ( session != null ) // can be null due to API backwards compatibility
         {
-            String mavenVersion = session.getExecutionProperties().getProperty( "maven.version" );
+            String mavenVersion = session.getSystemProperties().getProperty( "maven.version" );
             if ( mavenVersion != null )
             {
                 createdBy += " " + mavenVersion;
@@ -613,7 +664,6 @@ public class MavenArchiver
         addManifestAttribute( m, entries, "Created-By", createdBy );
     }
 
-
     private Artifact findArtifactWithFile( Set<Artifact> artifacts, File file )
     {
         for ( Artifact artifact : artifacts )
